Struct ZwlrOutputPowerV1
pub struct ZwlrOutputPowerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
adjust power management mode for an output
This object offers requests to set the power management mode of an output.
See also the Event enum for this interface.
Implementations
impl ZwlrOutputPowerV1
impl ZwlrOutputPowerV1
pub fn set_mode(&self, mode: Mode)
pub fn set_mode(&self, mode: Mode)
Set an outputs power save mode
Set an output’s power save mode to the given mode. The mode change is effective immediately. If the output does not support the given mode a failed event is sent.
pub fn destroy(&self)
pub fn destroy(&self)
destroy this power management
Destroys the output power management mode control object.